pub fn cmd_while<Ctx>(interp: &mut Interp<Ctx>, argv: &[Value]) -> MoltResultExpand description
while test command
A standard “while” loop. test is a boolean expression; command is a script to execute so long as the expression is true.
pub fn cmd_while<Ctx>(interp: &mut Interp<Ctx>, argv: &[Value]) -> MoltResultA standard “while” loop. test is a boolean expression; command is a script to execute so long as the expression is true.