VarName

Struct VarName 

pub struct VarName { /* private fields */ }
In TCL, variable references have two forms. A string like “some_var(some_index)” is the name of an array element; any other string is the name of a scalar variable. This struct is used when parsing variable references. The name is the variable name proper; the index is either None for scalar variables or Some(String) for array elements.

The Molt interp’s variable access API usually handles this automatically. Should a command need to distinguish between the two cases it can do so by using the the Value struct’s Value::as_var_name method.

Implementations

Source

impl VarName

pub fn scalar(name: String) -> Self

Creates a scalar VarName given the variable’s name.

pub fn array(name: String, index: String) -> Self

Creates an array element VarName given the element’s variable name and index string.

pub fn name(&self) -> &str

Returns the parsed variable name.

pub fn index(&self) -> Option<&str>

Returns the parsed array index, if any.